@@ -12,6 +12,7 @@ from multiqc.plots import bargraph, linegraph
 # Initialize log
 log = logging.getLogger(__name__)
 
+
 class MultiqcModule(BaseMultiqcModule):
     """FLASh MultiQC module
 
@@ -19,18 +20,19 @@ class MultiqcModule(BaseMultiqcModule):
       use_output_name: true - use first output filename as sample name
         default uses first input filename in log
     """
+
     def __init__(self):
         # Initialise the parent object
         super(MultiqcModule, self).__init__(
-            name = 'FLASh',
-            anchor = 'flash',
-            href = "https://ccb.jhu.edu/software/FLASH/",
-            info = "is a very fast and accurate software tool to merge paired-end reads from next-generation sequencing experiments."
+            name="FLASh",
+            anchor="flash",
+            href="https://ccb.jhu.edu/software/FLASH/",
+            info="is a very fast and accurate software tool to merge paired-end reads from next-generation sequencing experiments.",
         )
 
         # Find all log files with flash msgs
         self.flash_data = OrderedDict()
-        for logfile in self.find_log_files('flash/log'):
+        for logfile in self.find_log_files("flash/log"):
             self.flash_data.update(self.parse_flash_log(logfile))
 
         # ignore sample names
@@ -44,11 +46,10 @@ class MultiqcModule(BaseMultiqcModule):
             self.stats_table(self.flash_data)
 
             self.add_section(
-                name='Read combination statistics',
-                anchor='flash-bargraph',
-                plot=self.summary_plot(self.flash_data))
+                name="Read combination statistics", anchor="flash-bargraph", plot=self.summary_plot(self.flash_data)
+            )
 
-            self.write_data_file(self.flash_data, 'multiqc_flash_combo_stats')
+            self.write_data_file(self.flash_data, "multiqc_flash_combo_stats")
 
         except UserWarning:
             pass
@@ -67,16 +68,17 @@ class MultiqcModule(BaseMultiqcModule):
     def split_log(logf):
         """split concat log into individual samples"""
         flashpatt = re.compile(
-            r'\[FLASH\] Fast Length Adjustment of SHort reads\n(.+?)\[FLASH\] FLASH', flags=re.DOTALL)
+            r"\[FLASH\] Fast Length Adjustment of SHort reads\n(.+?)\[FLASH\] FLASH", flags=re.DOTALL
+        )
         return flashpatt.findall(logf)
 
     @staticmethod
     def get_field(field, slog, fl=False):
         """parse sample log for field
-           set fl=True to return a float
-           otherwise, returns int
+        set fl=True to return a float
+        otherwise, returns int
         """
-        field += r'\:\s+([\d\.]+)'
+        field += r"\:\s+([\d\.]+)"
         match = re.search(field, slog)
         if match:
             if fl:
@@ -84,45 +86,45 @@ class MultiqcModule(BaseMultiqcModule):
             return int(match.group(1))
         return 0
 
-    def clean_pe_name(self, nlog, root):
+    def clean_pe_name(self, nlog, logf):
         """additional name cleaning for paired end data"""
-        use_output_name = getattr(config, 'flash', {}).get('use_output_name', False)
+        use_output_name = getattr(config, "flash", {}).get("use_output_name", False)
         if use_output_name:
-            name = re.search(r'Output files\:\n\[FLASH\]\s+(.+?)\n', nlog)
+            name = re.search(r"Output files\:\n\[FLASH\]\s+(.+?)\n", nlog)
         else:
-            name = re.search(r'Input files\:\n\[FLASH\]\s+(.+?)\n', nlog)
+            name = re.search(r"Input files\:\n\[FLASH\]\s+(.+?)\n", nlog)
         if not name:
             return None
         name = name.group(1)
-        name = self.clean_s_name(name, root)
+        name = self.clean_s_name(name, logf)
         return name
 
     def parse_flash_log(self, logf):
         """parse flash logs"""
         data = OrderedDict()
-        samplelogs = self.split_log(logf['f'])
+        samplelogs = self.split_log(logf["f"])
         for slog in samplelogs:
             try:
                 sample = dict()
                 ## Sample name ##
-                s_name = self.clean_pe_name(slog, logf['root'])
+                s_name = self.clean_pe_name(slog, logf)
                 if s_name is None:
                     continue
-                sample['s_name'] = s_name
+                sample["s_name"] = s_name
 
                 ## Log attributes ##
-                sample['totalpairs'] = self.get_field('Total pairs', slog)
-                sample['discardpairs'] = self.get_field('Discarded pairs', slog)
-                sample['percdiscard'] = self.get_field('Percent Discarded', slog, fl=True)
-                sample['combopairs'] = self.get_field('Combined pairs', slog)
-                sample['inniepairs'] = self.get_field('Innie pairs', slog)
-                sample['outiepairs'] = self.get_field('Outie pairs', slog)
-                sample['uncombopairs'] = self.get_field('Uncombined pairs', slog)
-                sample['perccombo'] = self.get_field('Percent combined', slog, fl=True)
+                sample["totalpairs"] = self.get_field("Total pairs", slog)
+                sample["discardpairs"] = self.get_field("Discarded pairs", slog)
+                sample["percdiscard"] = self.get_field("Percent Discarded", slog, fl=True)
+                sample["combopairs"] = self.get_field("Combined pairs", slog)
+                sample["inniepairs"] = self.get_field("Innie pairs", slog)
+                sample["outiepairs"] = self.get_field("Outie pairs", slog)
+                sample["uncombopairs"] = self.get_field("Uncombined pairs", slog)
+                sample["perccombo"] = self.get_field("Percent combined", slog, fl=True)
 
                 data[s_name] = sample
             except Exception as err:
-                log.warning("Error parsing record in {}. {}".format(logf['fn'], err))
+                log.warning("Error parsing record in {}. {}".format(logf["fn"], err))
                 log.debug(traceback.format_exc())
                 continue
         return data
@@ -130,20 +132,20 @@ class MultiqcModule(BaseMultiqcModule):
     def stats_table(self, data):
         """Add percent combined to general stats table"""
         headers = OrderedDict()
-        headers['combopairs'] = {
-            'title': 'Combined pairs',
-            'description': 'Num read pairs combined',
-            'shared_key': 'read_count',
-            'hidden': True,
-            'scale': False
+        headers["combopairs"] = {
+            "title": "Combined pairs",
+            "description": "Num read pairs combined",
+            "shared_key": "read_count",
+            "hidden": True,
+            "scale": False,
         }
-        headers['perccombo'] = {
-            'title': '% Combined',
-            'description': '% read pairs combined',
-            'max': 100,
-            'min': 0,
-            'suffix': '%',
-            'scale': 'PiYG'
+        headers["perccombo"] = {
+            "title": "% Combined",
+            "description": "% read pairs combined",
+            "max": 100,
+            "min": 0,
+            "suffix": "%",
+            "scale": "PiYG",
         }
         self.general_stats_addcols(data, headers)
 
@@ -152,36 +154,21 @@ class MultiqcModule(BaseMultiqcModule):
         """Barplot of combined pairs"""
         cats = OrderedDict()
         cats = {
-            'combopairs': {
-                'name': 'Combined pairs',
-                'color': '#191970'
-            },
-            'inniepairs': {
-                'name': 'Combined innie pairs',
-                'color': '#191970'
-            },
-            'outiepairs': {
-                'name': 'Combined outie pairs',
-                'color': '#00A08A'
-            },
-            'uncombopairs': {
-                'name': 'Uncombined pairs',
-                'color': '#cd1076'
-            },
-            'discardpairs': {
-                'name': 'Discarded pairs',
-                'color': '#ffd700'
-            }
+            "combopairs": {"name": "Combined pairs", "color": "#191970"},
+            "inniepairs": {"name": "Combined innie pairs", "color": "#191970"},
+            "outiepairs": {"name": "Combined outie pairs", "color": "#00A08A"},
+            "uncombopairs": {"name": "Uncombined pairs", "color": "#cd1076"},
+            "discardpairs": {"name": "Discarded pairs", "color": "#ffd700"},
         }
         splotconfig = {
-            'id': 'flash_combo_stats_plot',
-            'title': 'FLASh: Read combination statistics',
-            'ylab': 'Number of read pairs'
+            "id": "flash_combo_stats_plot",
+            "title": "FLASh: Read combination statistics",
+            "ylab": "Number of read pairs",
         }
         # Only plot the combopairs category if we don't have inniepairs and outiepairs
         for s_name, d in data.items():
-            if (d['inniepairs'] > 0 or d['outiepairs'] > 0) and d['combopairs'] > 0:
-                del data[s_name]['combopairs']
+            if (d["inniepairs"] > 0 or d["outiepairs"] > 0) and d["combopairs"] > 0:
+                del data[s_name]["combopairs"]
 
         return bargraph.plot(data, cats, splotconfig)
 
@@ -191,33 +178,55 @@ class MultiqcModule(BaseMultiqcModule):
         nameddata = dict()
         data = dict()
         try:
-            for l in histf['f'].splitlines():
+            for l in histf["f"].splitlines():
                 s = l.split()
                 if s:
                     if len(s) != 2:
-                        raise RuntimeError("invalid format: " + str(len(s)) + " column(s) found in row. must be exactly 2.")
+                        raise RuntimeError(
+                            "invalid format: " + str(len(s)) + " column(s) found in row. must be exactly 2."
+                        )
                     data[int(s[0])] = int(s[1])
         except Exception as err:
-            log.warning("Error parsing %s. %s", histf['fn'], err)
+            log.warning("Error parsing %s. %s", histf["fn"], err)
             log.debug(traceback.format_exc())
         else:
             if data:
-                nameddata[histf['s_name']] = data
+                nameddata[histf["s_name"]] = data
             else:
-                log.debug("%s is empty.", histf['fn'])
+                log.debug("%s is empty.", histf["fn"])
         finally:
             return nameddata
 
     @staticmethod
     def get_colors(n):
         """get colors for freqpoly graph"""
-        cb_palette = ["#E69F00", "#56B4E9", "#009E73", "#F0E442", "#0072B2", "#D55E00",
-                      "#CC79A7","#001F3F", "#0074D9", "#7FDBFF", "#39CCCC", "#3D9970", "#2ECC40",
-                       "#01FF70", "#FFDC00", "#FF851B", "#FF4136", "#F012BE", "#B10DC9",
-                       "#85144B", "#AAAAAA", "#000000"]
+        cb_palette = [
+            "#E69F00",
+            "#56B4E9",
+            "#009E73",
+            "#F0E442",
+            "#0072B2",
+            "#D55E00",
+            "#CC79A7",
+            "#001F3F",
+            "#0074D9",
+            "#7FDBFF",
+            "#39CCCC",
+            "#3D9970",
+            "#2ECC40",
+            "#01FF70",
+            "#FFDC00",
+            "#FF851B",
+            "#FF4136",
+            "#F012BE",
+            "#B10DC9",
+            "#85144B",
+            "#AAAAAA",
+            "#000000",
+        ]
 
-        whole = int(n/22)
-        extra = (n % 22)
+        whole = int(n / 22)
+        extra = n % 22
         cols = cb_palette * whole
         if extra >= 0:
             cols.extend(cb_palette[0:extra])
@@ -231,22 +240,22 @@ class MultiqcModule(BaseMultiqcModule):
             tot = sum(val.values(), 0)
             rel_data[key] = {k: v / tot for k, v in val.items()}
         fplotconfig = {
-            'id': 'flash_freqpoly_plot',
-            'title': 'FLASh: Frequency of merged read lengths',
-            'xlab': 'Merged Read Length',
-            'ylab': 'Frequency',
-            'data_labels': [
-                {'name': 'Absolute', 'ylab': 'Frequency', 'xlab': 'Merged Read Length'},
-                {'name': 'Relative', 'ylab': 'Relative Frequency', 'xlab': 'Merged Read Length'}
+            "id": "flash_freqpoly_plot",
+            "title": "FLASh: Frequency of merged read lengths",
+            "xlab": "Merged Read Length",
+            "ylab": "Frequency",
+            "data_labels": [
+                {"name": "Absolute", "ylab": "Frequency", "xlab": "Merged Read Length"},
+                {"name": "Relative", "ylab": "Relative Frequency", "xlab": "Merged Read Length"},
             ],
-            'colors': dict(zip(data.keys(), MultiqcModule.get_colors(len(data))))
+            "colors": dict(zip(data.keys(), MultiqcModule.get_colors(len(data)))),
         }
         return linegraph.plot([data, rel_data], fplotconfig)
 
     def hist_results(self):
         """process flash numeric histograms"""
         self.hist_data = OrderedDict()
-        for histfile in self.find_log_files('flash/hist'):
+        for histfile in self.find_log_files("flash/hist"):
             self.hist_data.update(self.parse_hist_files(histfile))
 
         # ignore sample names
@@ -258,10 +267,10 @@ class MultiqcModule(BaseMultiqcModule):
             log.info("Found %d histogram reports", len(self.hist_data))
 
             self.add_section(
-                name = 'Frequency polygons of merged read lengths',
-                anchor = 'flash-histogram',
-                description = 'This plot is made from the numerical histograms output by FLASh.',
-                plot = self.freqpoly_plot(self.hist_data)
+                name="Frequency polygons of merged read lengths",
+                anchor="flash-histogram",
+                description="This plot is made from the numerical histograms output by FLASh.",
+                plot=self.freqpoly_plot(self.hist_data),
             )
 
         except UserWarning:
