@@ -15,18 +15,21 @@ from multiqc.modules.base_module import BaseMultiqcModule
 # Initialise the logger
 log = logging.getLogger(__name__)
 
-class MultiqcModule(BaseMultiqcModule):
 
+class MultiqcModule(BaseMultiqcModule):
     def __init__(self):
 
         # Initialise the parent object
-        super(MultiqcModule, self).__init__(name='SortMeRNA', anchor='sortmerna',
-        href='http://bioinfo.lifl.fr/RNA/sortmerna/',
-        info="is a program for filtering, mapping and OTU-picking NGS reads in metatranscriptomic and metagenomic data.")
+        super(MultiqcModule, self).__init__(
+            name="SortMeRNA",
+            anchor="sortmerna",
+            href="http://bioinfo.lifl.fr/RNA/sortmerna/",
+            info="is a program for filtering, mapping and OTU-picking NGS reads in metatranscriptomic and metagenomic data.",
+        )
 
         # Parse logs
         self.sortmerna = dict()
-        for f in self.find_log_files('sortmerna', filehandles=True):
+        for f in self.find_log_files("sortmerna", filehandles=True):
             self.parse_sortmerna(f)
 
         # Filter to strip out ignored sample names
@@ -36,20 +39,20 @@ class MultiqcModule(BaseMultiqcModule):
             raise UserWarning
 
         log.info("Found {} logs".format(len(self.sortmerna)))
-        self.write_data_file(self.sortmerna, 'multiqc_sortmerna')
+        self.write_data_file(self.sortmerna, "multiqc_sortmerna")
 
         # Get custom table header, default to 'rRNA'
-        tab_header = getattr(config, 'sortmerna', {}).get('seqname', '% rRNA')
+        tab_header = getattr(config, "sortmerna", {}).get("seqname", "% rRNA")
 
         # Add rRNA rate to the general stats table
         headers = OrderedDict()
-        headers['rRNA_pct'] = {
-            'title': tab_header,
-            'description': 'Percentage of reads matched to a SortMeRNA database',
-            'max': 100,
-            'min': 0,
-            'suffix': '%',
-            'scale': 'OrRd'
+        headers["rRNA_pct"] = {
+            "title": tab_header,
+            "description": "Percentage of reads matched to a SortMeRNA database",
+            "max": 100,
+            "min": 0,
+            "suffix": "%",
+            "scale": "OrRd",
         }
         self.general_stats_addcols(self.sortmerna, headers)
 
@@ -65,34 +68,38 @@ class MultiqcModule(BaseMultiqcModule):
 
         for l in f["f"]:
             if "Reads file" in l:
-                parts = re.split(':|=', l)
-                s_name = self.clean_s_name( parts[-1], f['root'] )
+                parts = re.split(":|=", l)
+                s_name = self.clean_s_name(parts[-1], f)
                 self.sortmerna[s_name] = dict()
-            if "Results:" in l and not post_results_start: # old versions
+            if "Results:" in l and not post_results_start:  # old versions
                 post_results_start = True
-            if "Total reads = " in l and not post_results_start: # v4.2.0 onwards
+            if "Total reads = " in l and not post_results_start:  # v4.2.0 onwards
                 post_results_start = True
             if not post_results_start:
                 continue
             if post_results_start and not post_database_start:
                 if "Total reads =" in l:
-                    m = re.search("\d+",l)
+                    m = re.search("\d+", l)
                     if m:
                         self.sortmerna[s_name]["total"] = int(m.group())
                     else:
                         err = True
                 elif "Total reads passing" in l:
-                    m = re.search("\d+",l)
+                    m = re.search("\d+", l)
                     if m:
                         self.sortmerna[s_name]["rRNA"] = int(m.group())
-                        self.sortmerna[s_name]["rRNA_pct"] = float(self.sortmerna[s_name]["rRNA"]) / float(self.sortmerna[s_name]["total"]) * 100
+                        self.sortmerna[s_name]["rRNA_pct"] = (
+                            float(self.sortmerna[s_name]["rRNA"]) / float(self.sortmerna[s_name]["total"]) * 100
+                        )
                     else:
                         err = True
                 elif "Total reads failing" in l:
-                    m = re.search("\d+",l)
+                    m = re.search("\d+", l)
                     if m:
                         self.sortmerna[s_name]["non_rRNA"] = int(m.group())
-                        self.sortmerna[s_name]["non_rRNA_pct"] = float(self.sortmerna[s_name]["non_rRNA"]) / float(self.sortmerna[s_name]["total"]) * 100
+                        self.sortmerna[s_name]["non_rRNA_pct"] = (
+                            float(self.sortmerna[s_name]["non_rRNA"]) / float(self.sortmerna[s_name]["total"]) * 100
+                        )
                     else:
                         err = True
             if post_database_start:
@@ -104,8 +111,8 @@ class MultiqcModule(BaseMultiqcModule):
                 db_number = db_number + 1
                 parts = re.split("\t+", l.strip())
                 if len(parts) == 2:
-                    db = os.path.splitext( os.path.basename( parts[0] ) )[0]
-                    pct = float(parts[1].replace('%', ''))
+                    db = os.path.splitext(os.path.basename(parts[0]))[0]
+                    pct = float(parts[1].replace("%", ""))
                     count = int(self.sortmerna[s_name]["total"]) * (pct / 100.0)
                     self.sortmerna[s_name][db + "_pct"] = pct
                     self.sortmerna[s_name][db + "_count"] = count
@@ -116,11 +123,11 @@ class MultiqcModule(BaseMultiqcModule):
                 post_database_start = True
         if err:
             log.warning("Error parsing data in: " + s_name)
-            self.sortmerna.pop(s_name, 'None')
+            self.sortmerna.pop(s_name, "None")
         s_name = None
 
-    def sortmerna_detailed_barplot (self):
-        """ Make the HighCharts HTML to plot the sortmerna rates """
+    def sortmerna_detailed_barplot(self):
+        """Make the HighCharts HTML to plot the sortmerna rates"""
 
         # Specify the order of the different possible categories
         keys = {}
@@ -131,13 +138,9 @@ class MultiqcModule(BaseMultiqcModule):
                     metrics.add(key)
 
         for key in metrics:
-            keys[key] = { 'name': key.replace("_count","") }
+            keys[key] = {"name": key.replace("_count", "")}
 
         # Config for the plot
-        pconfig = {
-            'id': 'sortmerna-detailed-plot',
-            'title': 'SortMeRNA: Hit Counts',
-            'ylab': 'Reads'
-        }
+        pconfig = {"id": "sortmerna-detailed-plot", "title": "SortMeRNA: Hit Counts", "ylab": "Reads"}
 
-        self.add_section( plot = bargraph.plot(self.sortmerna, sorted(keys), pconfig) )
+        self.add_section(plot=bargraph.plot(self.sortmerna, sorted(keys), pconfig))
